Index: dart/editor/tools/plugins/com.google.dart.tools.debug.core/src/com/google/dart/tools/debug/core/server/ServerRemoteScriptSourceContainer.java |
=================================================================== |
--- dart/editor/tools/plugins/com.google.dart.tools.debug.core/src/com/google/dart/tools/debug/core/server/ServerRemoteScriptSourceContainer.java (revision 37220) |
+++ dart/editor/tools/plugins/com.google.dart.tools.debug.core/src/com/google/dart/tools/debug/core/server/ServerRemoteScriptSourceContainer.java (working copy) |
@@ -63,9 +63,9 @@ |
int libraryId = Integer.parseInt(name.substring(0, index)); |
// TODO(devoncarew): change the buildin: format to an opaque token into a map; this will |
// let us eliminate the call to target.getMainIsolate(). |
String source = target.getConnection().getScriptSource( |
- target.getMainIsolate(), |
+ target.getCurrentIsolate(), |
libraryId, |
url); |
@@ -63,9 +63,9 @@ |
int libraryId = Integer.parseInt(name.substring(0, index)); |
// TODO(devoncarew): change the buildin: format to an opaque token into a map; this will |
- // let us eliminate the call to target.getMainIsolate(). |
+ // let us eliminate the call to target.getCurrentIsolate(). |
String source = target.getConnection().getScriptSource( |